# How to develop

## env

``` bash
hatch env create
hatch shell
```

## lint

``` bash
hatch env run -e lint fmt
```

## test

``` bash
hatch run test
```

## build

``` bash
hatch version 0.0.2
hatch build
```

## publish

``` bash
hatch publish
```
